# API Reference

These are the public classes and functions exposed by `boris-clip`. Useful if you want to use boris-clip programmatically rather than through the CLI.

## Models

::: boris_clip.models.Bout

::: boris_clip.models.ParsedAnnotations

::: boris_clip.models.VideoInfo

## Parsing

::: boris_clip.parse.parse_boris_file

## Extraction

::: boris_clip.clip.extract_all_clips

## Validation

::: boris_clip.validate.validate

## Video probing

::: boris_clip.probe.probe_video